@@ -662,18 +662,15 @@ void GetIdentifier (PINPUTBUF pibIn, PSTR szLex)
 
 void GetInteger (PINPUTBUF pibIn, PSTR szLex, PINT piLexType)
 {
-  PBUF pbufCur;
   int i = 0;
   char c;
   BOOL bHasSign = FALSE;
-  BOOL bLeadingDigits = FALSE;
   enum States
    {Start, Digits1, End} eState;
 
   if (!pibIn || !szLex || !piLexType)
     return;
 
-  pbufCur = pibIn->pbufCur;
   eState = Start;
   *piLexType = LX_NULL;
   while ((c = *pibIn->pbufCur) && i < MAX_LEX-1 && eState != End) {
@@ -683,7 +680,7 @@ void GetInteger (PINPUTBUF pibIn, PSTR szLex, PINT piLexType)
         if (!bHasSign && IsSign(c))
           bHasSign = TRUE;
         else if (isdigit(*pibIn->pbufCur)) {
-          bLeadingDigits = *piLexType = LX_INTEGER;
+          *piLexType = LX_INTEGER;
           eState = Digits1;
         } /* else */
         else
@@ -731,7 +728,6 @@ void GetInteger (PINPUTBUF pibIn, PSTR szLex, PINT piLexType)
 
 void GetNumber (PINPUTBUF pibIn, PSTR szLex, PINT piLexType)
 {
-  PBUF pbufCur;
   int i = 0;
   char c;
   BOOL bHasSign = FALSE;
@@ -742,7 +738,6 @@ void GetNumber (PINPUTBUF pibIn, PSTR szLex, PINT piLexType)
   if (!pibIn || !szLex || !piLexType)
     return;
 
-  pbufCur = pibIn->pbufCur;
   eState = Start;
   *piLexType = LX_NULL;
   while ((c = *pibIn->pbufCur) && i < MAX_LEX-1 && eState != End) {
@@ -849,7 +844,7 @@ void NextLex (PINPUTBUF pibIn, PSTRLEX szLex, PINT piLexType)
     if (!EOB(pibIn)) {
       c = *pibIn->pbufCur;
 
-      if (IsComment (&c)) { /* Comments can appear anywhere */
+      if (c == CH_COMMENT) { /* Comments can appear anywhere */
         fDone = FALSE; /* Continue until you get a lex */
         SkipComment (pibIn);
       } /* if */
@@ -871,7 +866,7 @@ void NextLex (PINPUTBUF pibIn, PSTRLEX szLex, PINT piLexType)
       } /* if */
 
       else
-      if (IsString (&c)) {
+      if (c == CH_STRDELIM) {
         *piLexType = LX_STRING;
         GetaString (pibIn, szLex);
       } /* if */
@@ -909,24 +904,24 @@ void NextLex (PINPUTBUF pibIn, PSTRLEX szLex, PINT piLexType)
 
 void PreventLexSplit (PINPUTBUF pibIn, int iOffset)
 {
-  long lFilePos, lDelta;
+  long lDelta;
   PBUF pbufEOB = pibIn->pbufOrg + iOffset;
   PBUF pbufEOBOld;
 
-  if (!EOB(pibIn)        /* If not EOB, use all of input, otherwise... */
-      || (iOffset == BUFFER_SIZE)) {    /* No room for NULL */
+  if (!EOB(pibIn) /* If not EOB, use all of input, otherwise... */
+      || (iOffset == BUFFER_SIZE)) { /* No room for NULL */
 
-    pbufEOBOld = pbufEOB;        /* Save EOB */
-    lFilePos = ftell (pibIn->pfileIn);    /* Save position */
+    pbufEOBOld = pbufEOB;  /* Save EOB */
     while (*(--pbufEOB) != CH_EOLN)
-      ;                /* Move EOB to last EOLN */
-    *pbufEOB = '\0';        /* Overwrite EOLN with NULL */
+      ; /* Move EOB to last EOLN */
+
+    *pbufEOB = '\0'; /* Overwrite EOLN with NULL */
 
     if ((lDelta = (long) (pbufEOB - pbufEOBOld)))
-      fseek (pibIn->pfileIn, lDelta, SEEK_CUR);    /* Backup file ptr */
-  } /* if */
-
-  else *pbufEOB = '\0'; /* Append NULL */
+      fseek (pibIn->pfileIn, lDelta, SEEK_CUR); /* Backup file ptr */
+  } 
+  else
+    *pbufEOB = '\0'; /* Append NULL */
 
 } /* PreventLexSplit */
 
@@ -1102,8 +1097,10 @@ void GetStatement (PINPUTBUF pibIn, PSTR szStmt)
                iParCount++;
                bParOpen = TRUE;
             }
-            if ((char) szStmt[i-1] == ')') iParCount--;
-            if ((iParCount == 0) && bParOpen) bParOpen = FALSE;
+            if ((char) szStmt[i-1] == ')')
+              iParCount--;
+            if ((iParCount == 0) && bParOpen) 
+              bParOpen = FALSE;
           } /* if */
           else {
             if (bParOpen)
@@ -1114,7 +1111,7 @@ void GetStatement (PINPUTBUF pibIn, PSTR szStmt)
         }
       } /* if pibIn->pbufCur */
       else
-      fDone = (FillBuffer (pibIn, BUFFER_SIZE) == EOF);
+        fDone = (FillBuffer (pibIn, BUFFER_SIZE) == EOF);
     } /* while */
 
     /* remove white spaces going backward - FB 28/2/98 */
@@ -1188,7 +1185,7 @@ int SkipWhitespace (PINPUTBUF pibIn)
 
   while (isspace(c = *pibIn->pbufCur) || c == CH_COMMENT) {
     fSkipped = 1;
-    if (IsComment(&c))
+    if (c == CH_COMMENT)
       SkipComment (pibIn);
 
     else {
