@@ -81,8 +81,7 @@ BOOL IsMathFunc (PSTR sz)
 {
   int i = 0;
 
-  while (*vrgszMathFuncs[i]
-         && strcmp (vrgszMathFuncs[i], sz))
+  while (*vrgszMathFuncs[i] && strcmp (vrgszMathFuncs[i], sz))
     i++;
 
   return (*vrgszMathFuncs[i]);
@@ -90,6 +89,24 @@ BOOL IsMathFunc (PSTR sz)
 }  /* IsMathFunc */
 
 
+/* ----------------------------------------------------------------------------
+   Check if the string passed corresponds to the CalcDelay function call. If
+   yes sets the global bDelays flag 
+*/
+BOOL IsDelayFunc (BOOL *bDelays, PSTR sz)
+{
+  BOOL bIsDelay;
+
+  bIsDelay = (!strcmp ("CalcDelay", sz));
+
+  if (bIsDelay && !(*bDelays))
+    *bDelays = TRUE;
+
+  return (bIsDelay);
+
+}  /* IsDelayFunc */
+
+
 /* ----------------------------------------------------------------------------
 */
 BOOL VerifyEqn (PINPUTBUF pibIn, PSTR szEqn)
@@ -126,12 +143,13 @@ BOOL VerifyEqn (PINPUTBUF pibIn, PSTR szEqn)
           /* Allowable identifiers are declared variables,
              C functions, and the time variable  */
           if (!(bOK = (GetVarType (pinfo->pvmGloVars, szLex) || 
-                      IsMathFunc (szLex) || 
-                      ((pinfo->wContext == CN_DYNAMICS || 
-                        pinfo->wContext == CN_SCALE ||
-                        pinfo->wContext == CN_CALCOUTPUTS) && 
-                       !(strcmp(szLex, VSZ_TIME) && 
-                         strcmp(szLex, VSZ_TIME_SBML))))))
+                       IsMathFunc  (szLex) || 
+		       IsDelayFunc (&(pinfo->bDelays), szLex) || 
+                       ((pinfo->wContext == CN_DYNAMICS || 
+                         pinfo->wContext == CN_SCALE ||
+                         pinfo->wContext == CN_CALCOUTPUTS) && 
+                        !(strcmp(szLex, VSZ_TIME) && 
+                          strcmp(szLex, VSZ_TIME_SBML))))))
              ReportError (pibIn, RE_UNDEFINED | RE_FATAL, szLex, NULL);
           }
 
@@ -513,12 +531,9 @@ void DefineCalcOutEqn (PINPUTBUF pibIn, PSTR szName, PSTR szEqn, HANDLE hType)
     if (!hType) /* Original type is NULL */
       AddEquation (&pinfo->pvmGloVars, szName, NULL, hNewType);
     
-    if ((hType & ID_LOCALCALCOUT) || /* Many per local */
-        !GetVarPTR (pinfo->pvmCalcOutEqns, szName)) /* 1 eqn per parm */
-      AddEquation (&pinfo->pvmCalcOutEqns, szName, szEqn, hNewType);
-    
-    else
-      ReportError (pibIn, RE_REDEF | RE_WARNING, szName, "* Ignoring");    
+    /* FB 27 April 2013: allow redefition of output variables */
+    AddEquation (&pinfo->pvmCalcOutEqns, szName, szEqn, hNewType);
+
   }
 
   pibIn->iLNPrev = pibIn->iLineNum; /* Update prev eqn line num */
