@@ -178,11 +178,9 @@ int WriteOneName (PFILE pfile, PVMMAPSTRCT pvm, PVOID pInfo)
 */
 void WriteHeader (PFILE pfile, PSTR szName, PVMMAPSTRCT pvmGlo)
 {
-  struct tm *ptm; /* Local time struct */
   time_t ttTime;
 
   time (&ttTime);
-  ptm = localtime (&ttTime);
 
   if (fprintf (pfile, "/* %s\n", szName) < 0)
     ReportError (NULL, RE_CANNOTOPEN | RE_FATAL,
@@ -628,8 +626,8 @@ void TranslateEquation (PFILE pfile, PSTR szEqn, long iEqType)
       if (bDelayCall) {  
         // do not translate the 1st param of CalcDelay but check it
         PVMMAPSTRCT pvm = NULL;
-        if ((pvm = GetVarPTR(vpvmGloVarList, szLex)) && 
-            (TYPE(pvm) == ID_STATE) || (TYPE(pvm) == ID_OUTPUT)) {
+        if (((pvm = GetVarPTR(vpvmGloVarList, szLex)) && 
+	     (TYPE(pvm) == ID_STATE)) || (TYPE(pvm) == ID_OUTPUT)) {
           fprintf (pfile, "ID_%s", szLex);
           // add the automatic time variable
           fprintf (pfile, ", (*pdTime)");
