@@ -467,7 +467,10 @@ void DoMarkov (PANALYSIS panal)
 
     /* skip the first line.  This allows a MC output file to be used
        directly as a restart file. */
-    fscanf (pfile, "%*[^\n]");  getc(pfile);
+    if (!fscanf (pfile, "%*[^\n]"))
+      ReportError (NULL, RE_READERROR | RE_FATAL, panal->gd.szGdata, NULL);
+    else 
+      getc(pfile);
 
     TraverseLevels (pLevel0, ReadData, pfile, NULL);
 
@@ -1082,7 +1085,7 @@ double LnDensity (PMCVAR pMCVar, PANALYSIS panal)
     }
   }
   else if (pMCVar->iType == MCV_GENLOGNORMAL || 
-	   pMCVar->iType == MCV_STUDENTT) {
+           pMCVar->iType == MCV_STUDENTT) {
     if (dParm1 < 0) {
       printf ("Error: parameter %g out of bounds in LnDensity\n",dParm1);
       exit (0);
@@ -1281,7 +1284,7 @@ double LnDensity (PMCVAR pMCVar, PANALYSIS panal)
         exit (0);
       }
       /* This is relative stdev of lognormal part -- dMin is sigma for the
-	 lognormal part */
+         lognormal part */
       dTmp = sqrt(exp(pow(dMin,2)) * (exp(pow(dMin,2)) - 1)); 
       /* This is the transformation parameter lambda */
       dTmp2 = pow(dParm2/dTmp,2);
@@ -1290,22 +1293,22 @@ double LnDensity (PMCVAR pMCVar, PANALYSIS panal)
       /* This is the transformed theta -- use Taylor series for 
          negative dTheta when lambda/dTheta^2 < 0.01 */
       if ((dTheta < 0) && (dTmp2 < (0.01*dTheta*dTheta)))
-	dTmp4 = log(dTmp2/(-2*dTheta)*(1+0.25*dTmp2/pow(dTheta,2)));
+        dTmp4 = log(dTmp2/(-2*dTheta)*(1+0.25*dTmp2/pow(dTheta,2)));
       else
-	dTmp4 = log(dTheta + sqrt(pow(dTheta,2) + dTmp2));
+        dTmp4 = log(dTheta + sqrt(pow(dTheta,2) + dTmp2));
       /* Normal log-density minus log-jacobian */
       return lnDFNormal( dTmp4, dTmp3, dTmp ) - 0.5*log(pow(dTmp4,2) + dTmp2);
 
-    case MCV_STUDENTT: /* Student T, dParm1 is dof, dParm2 is m, dMin is sigma */
+  case MCV_STUDENTT: // Student t, dParm1 is dof, dParm2 is m, dMin is sigma
       if (dParm1 <= 0) {
         printf ("Error: bad dof for Student-T variate"
-		"in LnDensity\n");
+                "in LnDensity\n");
         exit(0);
       }
       dTmp = (dParm1 + 1)/ 2;
       return (lnGamma(dTmp) - lnGamma(dParm1 / 2)
-	      -0.5 * log(dParm1 * PI *dMin *dMin)
-	      -dTmp * log(1 + pow((dTheta - dParm2) / dMin, 2) / dParm1));
+              -0.5 * log(dParm1 * PI *dMin *dMin)
+              -dTmp * log(1 + pow((dTheta - dParm2) / dMin, 2) / dParm1));
 
     case MCV_CAUCHY:
     case MCV_HALFCAUCHY: /* dParm1 is scale */
@@ -1723,7 +1726,10 @@ void ReadRestart (FILE *pfileRestart, long nThetas,
 
   /* skip the first line.  This allows a MC output file to be used
      directly as a restart file. */
-  fscanf (pfileRestart,  "%*[^\n]");  getc(pfileRestart);
+  if (!fscanf (pfileRestart,  "%*[^\n]")) 
+    ReportError (NULL, RE_READERROR | RE_FATAL, "Restart file", NULL);
+  else 
+    getc(pfileRestart);
 
   /* as long as we have not reached the end of the file we keep reading lines
      and overwriting the thetas, they keep only their last value.
@@ -1745,7 +1751,10 @@ void ReadRestart (FILE *pfileRestart, long nThetas,
 
     /* Throw away remainder of line. This allows a MC output file to be used
        directly as a restart file. */
-    fscanf (pfileRestart,  "%*[^\n]"); getc(pfileRestart);
+    if (!fscanf (pfileRestart,  "%*[^\n]")) 
+      ReportError (NULL, RE_READERROR | RE_FATAL, "Restart file", NULL);
+    else
+      getc(pfileRestart);
 
     /* update prgdSumProd */
     for (i = 0; i < nThetas; i++)
@@ -1790,8 +1799,10 @@ void ReadRestart2 (FILE *pfileRestart, long nThetas, int nInvTemperatures,
 
   /* skip the first line. This allows a MC output file to be used
      directly as a restart file. */
-  fscanf (pfileRestart, "%*[^\n]"); 
-  getc(pfileRestart);
+  if (!fscanf (pfileRestart, "%*[^\n]"))
+    ReportError (NULL, RE_READERROR | RE_FATAL, "Restart file", NULL);
+  else
+    getc(pfileRestart);
 
   /* as long as we have not reached the end of the file we keep reading lines
      and overwriting the thetas, they keep only their last value.
@@ -1823,7 +1834,10 @@ void ReadRestart2 (FILE *pfileRestart, long nThetas, int nInvTemperatures,
 
     /* Throw away remainder of line. This allows a MC output file to be used
        directly as a restart file. */
-    fscanf (pfileRestart,  "%*[^\n]"); getc(pfileRestart);
+    if (!fscanf (pfileRestart,  "%*[^\n]")) 
+      ReportError (NULL, RE_READERROR | RE_FATAL, "Restart file", NULL);
+    else
+      getc(pfileRestart);
 
     *pindexT = iT;
     for (i = 0; i < nInvTemperatures; i++) 
@@ -1957,10 +1971,9 @@ long SampleTemperature (PGIBBSDATA pgd, double dLnPrior, double dLnData)
   }
 
   /* Test the temperature */
-
-  if (Test2 (pgd, indexT, indexT_new, dLnPrior, dLnData, 
-             pgd->attemptedTempe, pgd->rgdlnPi[indexT], 
-             pgd->rgdlnPi[indexT_new])) {   
+  if (TestTemper (pgd, indexT, indexT_new, dLnPrior, dLnData, 
+                  pgd->attemptedTempe, pgd->rgdlnPi[indexT], 
+                  pgd->rgdlnPi[indexT_new])) {   
     /* jump */
     return (indexT_new);
   }
@@ -2009,11 +2022,11 @@ void SampleThetas (PLEVEL plevel, char **args)
   long *pnUpdateAt = (long *) args[3];
   long *pnTotal = (long *) args[4];
 
-  double dLnPrior, dLnLike, dLnData;
-  double dLnPriorNew, dLnLikeNew, dLnDataNew;
+  double dLnPrior, dLnLike, dLnData, dLnKern;
+  double dLnPriorNew, dLnLikeNew, dLnDataNew, dLnKernNew;
   double dTheta, dJumps;
   PMCVAR pMCVar;
-  long  n;
+  long   n;
 
   /* Set level sequence. This is needed to call RunExpt from the middle
      of the tree with the right initialization of the nodes above */
@@ -2028,9 +2041,9 @@ void SampleThetas (PLEVEL plevel, char **args)
     if (pMCVar->bIsFixed)
       goto WriteIt;
 
-    /* Compute prior and likelihood */
+    // Compute prior and likelihood
     dLnPrior = LnDensity (pMCVar, panal);
-    dLnLike = LnLike (pMCVar, panal);
+    dLnLike  = LnLike (pMCVar, panal);
 
     dLnData = 0.0;
 
@@ -2104,16 +2117,28 @@ void SampleThetas (PLEVEL plevel, char **args)
 
       pMCVar->lJumps = 0; /* reset the jumps counter */
 
-    }
+    } // end of kernel stuff
+
+    // Compute density under jump kernel
+    dLnKern  = log(CDFNormal ((MaxMCVar(pMCVar) - pMCVar->dVal) / 
+                              pMCVar->dKernelSD) -
+                   CDFNormal ((MinMCVar(pMCVar) - pMCVar->dVal) / 
+                              pMCVar->dKernelSD));
 
     /* sample a new value */
     pMCVar->dVal = SampleTheta (pMCVar);
 
-    /* recompute prior and likelihood */
-    dLnPriorNew = LnDensity (pMCVar, panal);
-    dLnLikeNew = LnLike (pMCVar, panal);
+    // update density under jump kernel
+    dLnKernNew  =  log(CDFNormal ((MaxMCVar(pMCVar) - pMCVar->dVal) / 
+                                  pMCVar->dKernelSD) -
+                       CDFNormal ((MinMCVar(pMCVar) - pMCVar->dVal) / 
+                                  pMCVar->dKernelSD));
 
-    dLnDataNew = 0.0;
+    // update prior and likelihood
+    dLnPriorNew = LnDensity (pMCVar, panal);
+    dLnLikeNew  = LnLike (pMCVar, panal);
+
+    dLnDataNew  = 0.0;
 
     /* If data are dependent compute the data likelihood */
     if (pMCVar->bExptIsDep) {
@@ -2129,8 +2154,9 @@ void SampleThetas (PLEVEL plevel, char **args)
     }
 
     /* Test the results and act accordingly */
-    if (!Test (pgd, pMCVar->bExptIsDep, dLnPrior, dLnPriorNew, dLnLike,
-               dLnLikeNew, dLnData, dLnDataNew)) {
+    if (!TestImpRatio (pgd, pMCVar->bExptIsDep, dLnKern, dLnKernNew,
+                       dLnPrior, dLnPriorNew, 
+                       dLnLike, dLnLikeNew, dLnData, dLnDataNew)) {
       pMCVar->dVal = dTheta;
 
       if(pMCVar->bExptIsDep)
@@ -2173,8 +2199,8 @@ void SampleThetasTempered (PLEVEL plevel, char **args)
   long *pnTotal = (long *) args[4];
   long *pindexT = (long *) args[5];
 
-  double dLnPrior, dLnLike, dLnData;
-  double dLnPriorNew, dLnLikeNew, dLnDataNew;
+  double dLnPrior, dLnLike, dLnData, dLnKern;
+  double dLnPriorNew, dLnLikeNew, dLnDataNew, dLnKernNew;
   double dTheta, dJumps, old_dKernelSD;
   PMCVAR pMCVar;
   long   n;
@@ -2268,7 +2294,7 @@ void SampleThetasTempered (PLEVEL plevel, char **args)
 
       pMCVar->lJumps = 0; /* reset the jumps counter */
 
-    }
+    } // end kernel updating stuff
 
     /* sample a new value */
 
@@ -2289,9 +2315,21 @@ void SampleThetasTempered (PLEVEL plevel, char **args)
     if (pMCVar->dKernelSD > pMCVar->dMaxKernelSD)
       pMCVar->dKernelSD = pMCVar->dMaxKernelSD;
 
+    // Compute density under jump kernel
+    dLnKern  = log(CDFNormal ((MaxMCVar(pMCVar) - pMCVar->dVal) / 
+                              pMCVar->dKernelSD) -
+                   CDFNormal ((MinMCVar(pMCVar) - pMCVar->dVal) / 
+                              pMCVar->dKernelSD));
+
     /* sample a new value */
     pMCVar->dVal = SampleTheta (pMCVar);
 
+    // update density under jump kernel
+    dLnKernNew  =  log(CDFNormal ((MaxMCVar(pMCVar) - pMCVar->dVal) / 
+                                  pMCVar->dKernelSD) -
+                       CDFNormal ((MinMCVar(pMCVar) - pMCVar->dVal) / 
+                                  pMCVar->dKernelSD));
+
     /* recompute prior and likelihood */
     dLnPriorNew = LnDensity (pMCVar, panal);
     dLnLikeNew = LnLike (pMCVar, panal);
@@ -2311,8 +2349,10 @@ void SampleThetasTempered (PLEVEL plevel, char **args)
     }
 
     /* Test the results and act accordingly */
-    if (!Test1 (pgd, pMCVar->bExptIsDep, dLnPrior, dLnPriorNew, dLnLike,
-                dLnLikeNew, dLnData, dLnDataNew, *pindexT)) {
+    if (!TestImpRatioTemper (pgd, pMCVar->bExptIsDep, dLnKern, dLnKernNew,
+                             dLnPrior, dLnPriorNew,
+                             dLnLike, dLnLikeNew, dLnData, dLnDataNew, 
+                             *pindexT)) {
       pMCVar->dVal = dTheta;
        if(pMCVar->bExptIsDep)
         TraverseLevels1 (plevel, RestoreLikelihoods, NULL);
@@ -2352,6 +2392,7 @@ void SampleThetaVector (PLEVEL pLevel, PANALYSIS panal, long nThetas,
 {
   register long i, j;
   double dTmp, dAccept, dLnPrior_old, dLnData_old;
+  BOOL   bInBounds;
 
   static long lAccepted = 0;
   static double dJumpSpread;
@@ -2402,13 +2443,13 @@ void SampleThetaVector (PLEVEL pLevel, PANALYSIS panal, long nThetas,
       /* try to save the computation by zeroing all non-diagonal elements */
       for (i = 0; i < nThetas; i++)
         for (j = 0; j < nThetas; j++) {
-                if (i == j)
+          if (i == j)
             prgdVariance[i][j] = prgdSumProd[i][j] / (double) (iter);
           else
             prgdVariance[i][j] = 0.0;
         }
 
-        /* if is still does not work, exit */
+        /* if it still does not work, exit */
       if (!Cholesky (prgdVariance, prgdComponent, nThetas)) {
         printf ("Error: impossible to compute a jumping kernel - Exiting."
                 "(You should check or change the restart file).\n\n");
@@ -2425,22 +2466,28 @@ void SampleThetaVector (PLEVEL pLevel, PANALYSIS panal, long nThetas,
   dLnPrior_old = *pdLnPrior;
   dLnData_old  = *pdLnData;
 
-  /* generate new pdTheta vector in the range of each element */
-  do {
-    for (i = 0; i < nThetas; i++) dNormVar[i] = NormalRandom(0.0, 1.0);
+  /* generate new pdTheta vector */
+  for (i = 0; i < nThetas; i++)
+    dNormVar[i] = NormalRandom(0.0, 1.0);
 
-    for (i = 0; i < nThetas; i++) {
-      dTmp = 0;
-      for (j = 0; j <= i; j++) /* only the non-zero part of prgdComponent */
-        dTmp = dTmp + dNormVar[j] * prgdComponent[i][j];
+  for (i = 0; i < nThetas; i++) {
+    dTmp = 0;
+    for (j = 0; j <= i; j++) /* only the non-zero part of prgdComponent */
+      dTmp = dTmp + dNormVar[j] * prgdComponent[i][j];
 
-      pdTheta[i] = pdTheta_old[i] + dJumpSpread * dTmp;
-    }
+    pdTheta[i] = pdTheta_old[i] + dJumpSpread * dTmp;
+  }
 
-    /* Set the dVals of the variables to the values sampled and check that
-       we are within bounds as a while condition */
-    nThetas = 0;
-  } while (!TraverseLevels1 (pLevel, SetMCVars, pdTheta, &nThetas, NULL));
+  /* Set the dVals of the variables to the values sampled and check that
+     we are within bounds */
+  nThetas = 0;
+  bInBounds = TraverseLevels1 (pLevel, SetMCVars, pdTheta, &nThetas, NULL);
+
+  if (!bInBounds) { // reject
+    for (i = 0; i < nThetas; i++) 
+      pdTheta[i] = pdTheta_old[i]; // restore
+    goto DontJump;
+  }
 
   /* Calculate the new prior */
   *pdLnPrior = 0.0;
@@ -2470,6 +2517,8 @@ void SampleThetaVector (PLEVEL pLevel, PANALYSIS panal, long nThetas,
     }
   }
 
+ DontJump:
+
   /* update arrays */
   for (i = 0; i < nThetas; i++) {
     pdSum[i] = pdSum[i] + pdTheta[i];
@@ -2622,12 +2671,11 @@ void ReadKernel (PLEVEL plevel, char **args)
       pMCVar = plevel->rgpMCVars[n];
 
       /* set the maximum kernel SD value */
-      if (pMCVar->iType == MCV_UNIFORM || pMCVar->iType == MCV_LOGUNIFORM )
-        pMCVar->dMaxKernelSD = *(pMCVar->pdParm[1]) / 6.0 - *(pMCVar->pdParm[0]) / 6.0;
-      else
-        pMCVar->dMaxKernelSD = *(pMCVar->pdParm[3]) / 6.0 - *(pMCVar->pdParm[2]) / 6.0;
+      pMCVar->dMaxKernelSD = (MaxMCVar(pMCVar) - MinMCVar(pMCVar)) / 6.0;
 
-      fscanf(pfile, "%lg", &(pMCVar->dKernelSD));
+      if (!fscanf(pfile, "%lg", &(pMCVar->dKernelSD))) {
+        ReportError (NULL, RE_READERROR | RE_FATAL, "kernel file", NULL);
+      }
     }
   }
 
@@ -2824,24 +2872,27 @@ int SumAllExpts (PLEVEL plevel, char **args)
 
 
 /* Function -------------------------------------------------------------------
-   Test
+   TestImpRatio
 
    Test prior, likelihood against random number between 0 and 1
 */
 
-BOOL Test (PGIBBSDATA pgd, BOOL bExptIsDep, 
-           double dLnPrior, double dLnPriorNew,
-           double dLnLike, double dLnLikeNew,
-           double dLnData, double dLnDataNew)
+BOOL TestImpRatio (PGIBBSDATA pgd,  BOOL bExptIsDep, 
+                   double dLnKern,  double dLnKernNew,
+                   double dLnPrior, double dLnPriorNew,
+                   double dLnLike,  double dLnLikeNew,
+                   double dLnData,  double dLnDataNew)
 {
   double dPjump;
 
-  if (dLnPriorNew == NULL_SUPPORT ||
+  if (dLnKernNew  == NULL_SUPPORT ||
+      dLnPriorNew == NULL_SUPPORT ||
       dLnLikeNew  == NULL_SUPPORT ||
       dLnDataNew  == NULL_SUPPORT)
     return FALSE;
 
-  dPjump = dLnPriorNew - dLnPrior + dLnLikeNew - dLnLike;
+  dPjump = dLnPriorNew - dLnPrior + dLnLikeNew - dLnLike + 
+           dLnKern - dLnKernNew;
 
   if (bExptIsDep)
     dPjump += dLnDataNew - dLnData;
@@ -2852,24 +2903,27 @@ BOOL Test (PGIBBSDATA pgd, BOOL bExptIsDep,
     if (pgd->nSimTypeFlag == 4)
       return ((BOOL) (0 <= dPjump));
     else {
-      printf ("Error: SimTypeFlag should be 0 or 4 in Test - Exiting.\n\n");
+      printf ("Error: SimTypeFlag should be 0 or 4 in TestImpRatio "
+              "- Exiting.\n\n");
       exit (0);
     }
   }
 
-} /* Test */
+} /* TestImpRatio */
+
 
 /* Function -------------------------------------------------------------------
-   Test1
+   TestImpRatioTemper
 
    Test prior, likelihood against a random number between 0 and 1 according to 
    the temperature
 */
 
-BOOL Test1 (PGIBBSDATA pgd, BOOL bExptIsDep,
-            double dLnPrior, double dLnPriorNew,
-            double dLnLike, double dLnLikeNew,
-            double dLnData, double dLnDataNew, long indexT)
+BOOL TestImpRatioTemper (PGIBBSDATA pgd,  BOOL bExptIsDep,
+                         double dLnKern,  double dLnKernNew,
+                         double dLnPrior, double dLnPriorNew,
+                         double dLnLike,  double dLnLikeNew,
+                         double dLnData,  double dLnDataNew, long indexT)
 {
   double dPjump;
 
@@ -2879,25 +2933,26 @@ BOOL Test1 (PGIBBSDATA pgd, BOOL bExptIsDep,
     return FALSE;
 
   dPjump = pgd->rgInvTemperatures[indexT] * 
-           (dLnPriorNew - dLnPrior + dLnLikeNew - dLnLike);
+           (dLnPriorNew - dLnPrior + dLnLikeNew - dLnLike + 
+            dLnKern - dLnKernNew);
 
   if (bExptIsDep)
     dPjump += pgd->rgInvTemperatures[indexT] *(dLnDataNew - dLnData);
 
   return ((BOOL) (log(Randoms()) <= dPjump));
 
-} /* Test1 */
+} /* TestImpRatioTemper */
 
 
 /* Function -------------------------------------------------------------------
-   Test2
+   TestTemper
 
    Test temperature against a random number between 0 and 1
 */
 
-BOOL Test2 (PGIBBSDATA pgd, long indexT, long indexT_new, double dLnPrior, 
-            double dLnData, long attemptedTempe,
-            double pseudo, double pseudonew)
+BOOL TestTemper (PGIBBSDATA pgd, long indexT, long indexT_new, double dLnPrior, 
+                 double dLnData, long attemptedTempe,
+                 double pseudo, double pseudonew)
 {
   double dPjump = 0;
   #define MINUSLN2  -0.6931471805599452862268
@@ -2915,7 +2970,7 @@ BOOL Test2 (PGIBBSDATA pgd, long indexT, long indexT_new, double dLnPrior,
 
   return ((BOOL) (log(Randoms()) <= dPjump));
 
-} /* Test2 */
+} /* TestTemper */
 
 
 /* Function -------------------------------------------------------------------
