@@ -129,17 +129,19 @@ int    SetMCVars (PLEVEL plevel, char **args);
 int    SumAllExpts (PLEVEL plevel, char **args);
 void   SetPointers (PLEVEL plevel, char **args);
 double Temper_probabilities(int n, long i, long j);
-BOOL   Test (PGIBBSDATA pgd, BOOL bExptIsDep,
-             double dLnPrior, double dLnPriorNew,
-             double dLnLike, double dLnLikeNew,
-             double dLnData, double dLnDataNew);
-BOOL   Test1 (PGIBBSDATA pgd, BOOL bExptIsDep, 
-              double dLnPrior, double dLnPriorNew,
-              double dLnLike, double dLnLikeNew,
-              double dLnData, double dLnDataNew, long indexT);
-BOOL   Test2 (PGIBBSDATA pgd, long indexT, long indexT_new, double dLnPrior, 
-              double dLnData, long attemptedTempe, 
-              double pseudo, double pseudonew);
+BOOL   TestImpRatio (PGIBBSDATA pgd,  BOOL bExptIsDep,
+                     double dLnKern,  double dLnKernNew,
+                     double dLnPrior, double dLnPriorNew,
+                     double dLnLike,  double dLnLikeNew,
+                     double dLnData,  double dLnDataNew);
+BOOL   TestImpRatioTemper (PGIBBSDATA pgd,  BOOL bExptIsDep, 
+                           double dLnKern,  double dLnKernNew,
+                           double dLnPrior, double dLnPriorNew,
+                           double dLnLike,  double dLnLikeNew,
+                           double dLnData,  double dLnDataNew, long indexT);
+BOOL   TestTemper (PGIBBSDATA pgd, long indexT, long indexT_new, 
+                   double dLnPrior, double dLnData, long attemptedTempe, 
+                   double pseudo, double pseudonew);
 void   TraverseLevels (PLEVEL plevel,
                        void (*routinePtr)(PLEVEL plevel, char **args), ...);
 int    TraverseLevels1 (PLEVEL plevel,
