@@ -646,25 +646,24 @@ void PromptFilenames (PSTR *pszFileIn, PSTR *pszFileOut)
   *pszFileOut = (PSTR) calloc (1, MAX_FILENAMESIZE);
 
   printf ("Input filename? ");
-#ifdef _MACOSLEVEL1_
-  scanf ("%[^:\f\r\v\n]", *pszFileIn);
-  getchar();
-#else
-  fgets (*pszFileIn, MAX_FILENAMESIZE, stdin);
-  *pszFileIn = strtok (*pszFileIn, " \t\n");
-#endif
+
+  if (!fgets (*pszFileIn, MAX_FILENAMESIZE, stdin)) {
+    ReportError (NULL, RE_READERROR | RE_FATAL, "stdin", NULL);
+  }
+  else
+    *pszFileIn = strtok (*pszFileIn, " \t\n");
 
   if (!(*pszFileIn)) /* Nothing entered, quit */
     return;
 
   if ((*pszFileIn)[0]) { /* Input file specified */
     printf ("Output filename? ");
-#ifdef _MACOSLEVEL1_
-    scanf ("%[^:\f\r\v\n]", *pszFileOut);
-#else
-    fgets (*pszFileOut, MAX_FILENAMESIZE, stdin);
-    *pszFileOut = strtok (*pszFileOut, " \t\n");
-#endif
+
+    if (!fgets (*pszFileOut, MAX_FILENAMESIZE, stdin)) {
+      ReportError (NULL, RE_READERROR | RE_FATAL, "stdin", NULL);
+    }
+    else
+      *pszFileOut = strtok (*pszFileOut, " \t\n");
   }
 
   if (!(*pszFileOut) || !(*pszFileOut)[0]) { /* If no output specified */
